@@ -19,7 +19,7 @@ def Statistics_OPT(opt_runs, margin, Mininbars = 0):
 
         countneg = sum(map(lambda x: x < 0, ExpClosedf['exp_close']))
         countzero = sum(map(lambda x: x == 0, ExpClosedf['exp_close']))
-        count_perc = round(DivByZero_int(countneg, (len(ExpCloseDF['exp_close']) - countzero)), 5)
+        count_perc = round(DivByZero_int(countneg, (len(ExpClosedf['exp_close']) - countzero)), 5)
         # count_perc = "{:.2%}".format(count_perc)
 
         trade_list = s.analyzers.trade_list.get_analysis()
